@@ -2,7 +2,7 @@ use warnings;
 
 package Git::Hooks::CheckDiff;
 # ABSTRACT: Git::Hooks plugin to enforce commit policies
-$Git::Hooks::CheckDiff::VERSION = '3.2.0';
+$Git::Hooks::CheckDiff::VERSION = '3.2.1';
 use v5.16.0;
 use utf8;
 use Carp;
@@ -14,9 +14,9 @@ my $PKG = __PACKAGE__;
 my $CFG = __PACKAGE__ =~ s/.*::/githooks./r;
 
 # Install hooks
-GITHOOKS_CHECK_AFFECTED_REFS \&_check_ref;
-GITHOOKS_CHECK_PRE_COMMIT    \&check_commit;
-GITHOOKS_CHECK_PATCHSET      \&check_patchset;
+GITHOOKS_CHECK_AFFECTED_REFS(\&_check_ref);
+GITHOOKS_CHECK_PRE_COMMIT(\&check_commit);
+GITHOOKS_CHECK_PATCHSET(\&check_patchset);
 
 sub check_commit {
     my ($git, $current_branch) = @_;
@@ -242,7 +242,7 @@ Git::Hooks::CheckDiff - Git::Hooks plugin to enforce commit policies
 
 =head1 VERSION
 
-version 3.2.0
+version 3.2.1
 
 =head1 SYNOPSIS
 
@@ -413,7 +413,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by CPQD <www.cpqd.com.br>.
+This software is copyright (c) 2022 by CPQD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
