@@ -2,7 +2,7 @@ use warnings;
 
 package Git::Hooks::CheckFile;
 # ABSTRACT: Git::Hooks plugin for checking files
-$Git::Hooks::CheckFile::VERSION = '3.2.0';
+$Git::Hooks::CheckFile::VERSION = '3.2.1';
 use v5.16.0;
 use utf8;
 use Carp;
@@ -520,9 +520,9 @@ sub check_patchset {
 # Install hooks
 my $options = {config => \&_setup_config};
 
-GITHOOKS_CHECK_AFFECTED_REFS \&check_ref,      $options;
-GITHOOKS_CHECK_PRE_COMMIT    \&check_commit,   $options;
-GITHOOKS_CHECK_PATCHSET      \&check_patchset, $options;
+GITHOOKS_CHECK_AFFECTED_REFS(\&check_ref, $options);
+GITHOOKS_CHECK_PRE_COMMIT(\&check_commit, $options);
+GITHOOKS_CHECK_PATCHSET(\&check_patchset, $options);
 
 1;
 
@@ -538,7 +538,7 @@ Git::Hooks::CheckFile - Git::Hooks plugin for checking files
 
 =head1 VERSION
 
-version 3.2.0
+version 3.2.1
 
 =head1 SYNOPSIS
 
@@ -855,7 +855,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by CPQD <www.cpqd.com.br>.
+This software is copyright (c) 2022 by CPQD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
