@@ -2,7 +2,7 @@ use warnings;
 
 package Git::Hooks::CheckJira;
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages
-$Git::Hooks::CheckJira::VERSION = '3.2.0';
+$Git::Hooks::CheckJira::VERSION = '3.2.1';
 use v5.16.0;
 use utf8;
 use Log::Any '$log';
@@ -512,11 +512,11 @@ my $options = {
     destroy => \&_disconnect_jira,
 };
 
-GITHOOKS_CHECK_AFFECTED_REFS \&check_ref,          $options;
-GITHOOKS_CHECK_PATCHSET      \&check_patchset,     $options;
-GITHOOKS_CHECK_MESSAGE_FILE  \&check_message_file, $options;
+GITHOOKS_CHECK_AFFECTED_REFS(\&check_ref, $options);
+GITHOOKS_CHECK_PATCHSET(\&check_patchset, $options);
+GITHOOKS_CHECK_MESSAGE_FILE(\&check_message_file, $options);
 
-POST_RECEIVE \&notify_affected_refs;
+POST_RECEIVE(\&notify_affected_refs);
 
 1;
 
@@ -532,7 +532,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 3.2.0
+version 3.2.1
 
 =head1 SYNOPSIS
 
@@ -1001,7 +1001,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by CPQD <www.cpqd.com.br>.
+This software is copyright (c) 2022 by CPQD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
