@@ -2,7 +2,7 @@ use warnings;
 
 package Git::Hooks::CheckLog;
 # ABSTRACT: Git::Hooks plugin to enforce commit log policies
-$Git::Hooks::CheckLog::VERSION = '3.2.0';
+$Git::Hooks::CheckLog::VERSION = '3.2.1';
 use v5.16.0;
 use utf8;
 use Log::Any '$log';
@@ -321,7 +321,7 @@ sub check_ref {
         $errors += message_errors($git, $commit, $commit->message);
     }
 
-    return $errors == 0;
+    return $errors;
 }
 
 sub check_patchset {
@@ -333,9 +333,9 @@ sub check_patchset {
 # Install hooks
 my $options = {config => \&_setup_config};
 
-GITHOOKS_CHECK_AFFECTED_REFS \&check_ref,          $options;
-GITHOOKS_CHECK_PATCHSET      \&check_patchset,     $options;
-GITHOOKS_CHECK_MESSAGE_FILE  \&check_message_file, $options;
+GITHOOKS_CHECK_AFFECTED_REFS(\&check_ref, $options);
+GITHOOKS_CHECK_PATCHSET(\&check_patchset, $options);
+GITHOOKS_CHECK_MESSAGE_FILE(\&check_message_file, $options);
 
 1;
 
@@ -351,7 +351,7 @@ Git::Hooks::CheckLog - Git::Hooks plugin to enforce commit log policies
 
 =head1 VERSION
 
-version 3.2.0
+version 3.2.1
 
 =head1 SYNOPSIS
 
@@ -658,7 +658,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by CPQD <www.cpqd.com.br>.
+This software is copyright (c) 2022 by CPQD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
