@@ -2,7 +2,7 @@ use warnings;
 
 package Git::Hooks::CheckRewrite;
 # ABSTRACT: Git::Hooks plugin for checking against unsafe rewrites
-$Git::Hooks::CheckRewrite::VERSION = '3.2.0';
+$Git::Hooks::CheckRewrite::VERSION = '3.2.1';
 use v5.16.0;
 use utf8;
 use Path::Tiny;
@@ -163,9 +163,9 @@ EOS
 }
 
 # Install hooks
-PRE_COMMIT  \&record_commit_parents;
-POST_COMMIT \&check_commit_amend;
-PRE_REBASE  \&check_rebase;
+PRE_COMMIT(\&record_commit_parents);
+POST_COMMIT(\&check_commit_amend);
+PRE_REBASE(\&check_rebase);
 
 1;
 
@@ -181,7 +181,7 @@ Git::Hooks::CheckRewrite - Git::Hooks plugin for checking against unsafe rewrite
 
 =head1 VERSION
 
-version 3.2.0
+version 3.2.1
 
 =head1 SYNOPSIS
 
@@ -251,7 +251,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by CPQD <www.cpqd.com.br>.
+This software is copyright (c) 2022 by CPQD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
