@@ -2,7 +2,7 @@ use warnings;
 
 package Git::Hooks::GerritChangeId;
 # ABSTRACT: Git::Hooks plugin to insert a Change-Id in a commit message
-$Git::Hooks::GerritChangeId::VERSION = '3.2.0';
+$Git::Hooks::GerritChangeId::VERSION = '3.2.1';
 use v5.16.0;
 use utf8;
 use Carp;
@@ -86,8 +86,8 @@ sub rewrite_message {
 }
 
 # Install hooks
-APPLYPATCH_MSG \&rewrite_message;
-COMMIT_MSG     \&rewrite_message;
+APPLYPATCH_MSG(\&rewrite_message);
+COMMIT_MSG(\&rewrite_message);
 
 1;
 
@@ -103,7 +103,7 @@ Git::Hooks::GerritChangeId - Git::Hooks plugin to insert a Change-Id in a commit
 
 =head1 VERSION
 
-version 3.2.0
+version 3.2.1
 
 =head1 SYNOPSIS
 
@@ -206,7 +206,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by CPQD <www.cpqd.com.br>.
+This software is copyright (c) 2022 by CPQD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
