@@ -2,7 +2,7 @@ use warnings;
 
 package Git::Hooks::PrepareLog;
 # ABSTRACT: Git::Hooks plugin to prepare commit messages before being edited
-$Git::Hooks::PrepareLog::VERSION = '3.2.0';
+$Git::Hooks::PrepareLog::VERSION = '3.2.1';
 use v5.16.0;
 use utf8;
 use Log::Any '$log';
@@ -130,7 +130,7 @@ sub prepare_message {
 }
 
 # Install hooks
-PREPARE_COMMIT_MSG \&prepare_message;
+PREPARE_COMMIT_MSG(\&prepare_message);
 
 1;
 
@@ -146,7 +146,7 @@ Git::Hooks::PrepareLog - Git::Hooks plugin to prepare commit messages before bei
 
 =head1 VERSION
 
-version 3.2.0
+version 3.2.1
 
 =head1 SYNOPSIS
 
@@ -315,7 +315,7 @@ Gustavo L. de M. Chaves <gnustavo@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by CPQD <www.cpqd.com.br>.
+This software is copyright (c) 2022 by CPQD <www.cpqd.com.br>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
